#[repr(u8)]pub enum PacketSignal {
SurbDistress = 0,
OutOfSurbs = 1,
}Expand description
Individual packet signals passed up between the packet sender and destination.
Variants
SurbDistress = 0
The other party is in a “SURB distress” state, potentially running out of SURBs soon.
Has no effect on packets that take the “forward path”.
OutOfSurbs = 1
The other party has run out of SURBs, and this was potentially the last message they could send.
Has no effect on packets that take the “forward path”.
Implies [SurbDistress].