pub struct PacketMessage<S: SphinxSuite, H: SphinxHeaderSpec, const P: usize>(PaddedPayload<P>, PhantomData<(S, H)>);Expand description
Additional encoding of a packet message that can be preceded by a number of SURBs.
Tuple Fields
0: PaddedPayload<P>1: PhantomData<(S, H)>Implementations
Sourceimpl<S: SphinxSuite, H: SphinxHeaderSpec, const P: usize> PacketMessage<S, H, P>
impl<S: SphinxSuite, H: SphinxHeaderSpec, const P: usize> PacketMessage<S, H, P>
Sourcepub const HEADER_LEN: usize = 1
pub const HEADER_LEN: usize = 1
Size of the message header.
This is currently 1 byte to indicate the number of SURBs that precede the message.
Sourcepub const MAX_SURBS_PER_MESSAGE: usize
pub const MAX_SURBS_PER_MESSAGE: usize
The maximum number of SURBs a packet message can hold, according to RFC-0003.
The number of SURBs in a PacketMessage is intentionally limited to 15, so that
the upper 4 bits remain reserved for additional flags.